import { Constructor } from '@s-libs/js-core';
import { Subject } from 'rxjs';
/**
 * Mixes in {@link InjectableSuperclass} as an additional superclass.
 *
 * ```ts
 * class MySubclass extends mixInInjectableSuperclass(MyOtherSuperclass) {
 *   subscribeWithAutoUnsubscribe(observable: Observable<any>) {
 *     this.subscribeTo(observable);
 *   }
 * }
 * ```
 */
export declare function mixInInjectableSuperclass<B extends Constructor>(Base: B): {
    new (...args: any[]): {
        "__#5@#destructionSubject": Subject<void>;
        /**
         * An observable that emits once when this object is destroyed, then completes.
         */
        destruction$: import("rxjs").Observable<void>;
        "__#5@#subscriptions": import("rxjs").Subscription;
        subscribeTo<T>(observable: import("rxjs").Observable<T>, next?: ((value: T) => void) | undefined, error?: ((error: any) => void) | undefined, complete?: (() => void) | undefined): void;
        manage(subscription: import("rxjs").Subscription): void;
        unsubscribe(): void;
    };
} & B;
declare const InjectableSuperclass_base: {
    new (...args: any[]): {
        "__#5@#destructionSubject": Subject<void>;
        /**
         * An observable that emits once when this object is destroyed, then completes.
         */
        destruction$: import("rxjs").Observable<void>;
        "__#5@#subscriptions": import("rxjs").Subscription;
        subscribeTo<T>(observable: import("rxjs").Observable<T>, next?: ((value: T) => void) | undefined, error?: ((error: any) => void) | undefined, complete?: (() => void) | undefined): void;
        manage(subscription: import("rxjs").Subscription): void;
        unsubscribe(): void;
    };
} & ObjectConstructor;
/**
 * Use as the superclass for anything managed by Angular's dependency injection for care-free use of `subscribeTo()`. It simply calls `unsubscribe()` when the object is destroyed. Note that the object must be created in an {@link https://angular.dev/guide/di/dependency-injection-context | injection context}.
 *
 * ```ts
 * @Injectable() // or @Component(), @Directive() or @Pipe(), but consider DirectiveSuperclass
 * class MyThing extends InjectableSuperclass {
 *   constructor(somethingObservable: Observable) {
 *     super();
 *     this.subscribeTo(somethingObservable);
 *   }
 * }
 * ```
 */
export declare abstract class InjectableSuperclass extends InjectableSuperclass_base {
}
export {};
